# Vendorized Schemas

These are vendored versions of the schemas referred to by the hooks.
For the exact list of schemas here, see the repo root for hook config.

## Licenses

Most of the schemas in this directory are provided by SchemaStore. They are
therefore licensed under the SchemaStore license, included in this directory.

The Azure pipelines schema is provided by Microsoft and is licensed under the
license for azure-pipelines-vscode.
